@@ -259,7 +259,7 @@ Usage::
     search_local_gateway_routes_paginator: SearchLocalGatewayRoutesPaginator = client.get_paginator("search_local_gateway_routes")
     search_transit_gateway_multicast_groups_paginator: SearchTransitGatewayMulticastGroupsPaginator = client.get_paginator("search_transit_gateway_multicast_groups")
 """
-from mypy_boto3_ec2.client import EC2Client, EC2Client as Client
+from mypy_boto3_ec2.client import EC2Client as Client, EC2Client
 from mypy_boto3_ec2.paginator import (
     DescribeByoipCidrsPaginator,
     DescribeCapacityReservationsPaginator,
